summaryrefslogtreecommitdiffstats
path: root/knode
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /knode
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'knode')
-rw-r--r--knode/articlewidget.cpp30
-rw-r--r--knode/headerview.cpp4
-rw-r--r--knode/knaccountmanager.cpp6
-rw-r--r--knode/knarticle.cpp2
-rw-r--r--knode/knarticlefactory.cpp12
-rw-r--r--knode/knarticlefilter.cpp6
-rw-r--r--knode/knarticlemanager.cpp22
-rw-r--r--knode/kncleanup.cpp6
-rw-r--r--knode/kncomposer.cpp20
-rw-r--r--knode/knconfigwidgets.cpp14
-rw-r--r--knode/knconvert.cpp6
-rw-r--r--knode/knfilterdialog.cpp2
-rw-r--r--knode/knfolder.cpp12
-rw-r--r--knode/knfoldermanager.cpp14
-rw-r--r--knode/knglobals.cpp4
-rw-r--r--knode/knglobals.h4
-rw-r--r--knode/kngroup.cpp14
-rw-r--r--knode/kngroup.h2
-rw-r--r--knode/kngroupbrowser.cpp2
-rw-r--r--knode/kngroupmanager.cpp6
-rw-r--r--knode/kngrouppropdlg.cpp2
-rw-r--r--knode/knhdrviewitem.cpp8
-rw-r--r--knode/knhdrviewitem.h2
-rw-r--r--knode/knjobdata.cpp4
-rw-r--r--knode/knjobdata.h2
-rw-r--r--knode/knmainwidget.cpp22
-rw-r--r--knode/knmainwidget.h4
-rw-r--r--knode/knmemorymanager.cpp4
-rw-r--r--knode/knnetaccess.cpp48
-rw-r--r--knode/knnntpaccount.cpp2
-rw-r--r--knode/knnntpclient.cpp12
-rw-r--r--knode/knprotocolclient.cpp6
-rw-r--r--knode/knserverinfo.cpp2
-rw-r--r--knode/utilities.cpp4
34 files changed, 155 insertions, 155 deletions
diff --git a/knode/articlewidget.cpp b/knode/articlewidget.cpp
index 272df836..2827d025 100644
--- a/knode/articlewidget.cpp
+++ b/knode/articlewidget.cpp
@@ -290,9 +290,9 @@ void ArticleWidget::readConfig()
mAttachmentStyle = conf->readEntry( "attachmentStyle", "inline" );
mHeaderStyle = conf->readEntry( "headerStyle", "fancy" );
KRadioAction *ra = 0;
- ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_attachments_%1").tqarg(mAttachmentStyle).latin1() ) );
+ ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_attachments_%1").arg(mAttachmentStyle).latin1() ) );
ra->setChecked( true );
- ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_headers_%1").tqarg(mHeaderStyle).latin1() ) );
+ ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_headers_%1").arg(mHeaderStyle).latin1() ) );
ra->setChecked( true );
delete mCSSHelper;
@@ -402,7 +402,7 @@ void ArticleWidget::displayArticle()
// check if codec is available
if ( text && !canDecodeText( text->contentType()->charset() ) ) {
html += TQString("<table width=\"100%\" border=\"0\"><tr><td bgcolor=\"#FF0000\">%1</td></tr></table>")
- .tqarg( i18n("Unknown charset. Default charset is used instead.") );
+ .arg( i18n("Unknown charset. Default charset is used instead.") );
kdDebug(5003) << k_funcinfo << "unknown charset = " << text->contentType()->charset() << endl;
}
@@ -560,8 +560,8 @@ void ArticleWidget::displayHeader()
if ( header ) {
headerHtml += "<tr>";
headerHtml+=TQString( "<td align=\"right\" valign=\"top\"><b>%1</b></td><td width=\"100%\">%2</td></tr>" )
- .tqarg( toHtmlString( header->type(), None ) + ": " )
- .tqarg( toHtmlString( header->asUnicodeString() , ParseURL ) );
+ .arg( toHtmlString( header->type(), None ) + ": " )
+ .arg( toHtmlString( header->asUnicodeString() , ParseURL ) );
delete header;
}
}
@@ -597,8 +597,8 @@ void ArticleWidget::displayHeader()
if ( hb->is("From") ) {
headerHtml += TQString( "<a href=\"mailto:%1\">%2</a>")
- .tqarg( KPIM::getEmailAddress( hb->asUnicodeString() ) )
- .tqarg( toHtmlString( hb->asUnicodeString(), None ) );
+ .arg( KPIM::getEmailAddress( hb->asUnicodeString() ) )
+ .arg( toHtmlString( hb->asUnicodeString(), None ) );
KMime::Headers::Base *orgHdr = mArticle->getHeaderByType( "Organization" );
if ( orgHdr && !orgHdr->isEmpty() ) {
headerHtml += "&nbsp;&nbsp;(";
@@ -636,7 +636,7 @@ void ArticleWidget::displayHeader()
if ( !xfhead.isEmpty() ) {
KPIM::KXFace xf;
xface = TQString::fromLatin1( "<div class=\"senderpic\"><img src=\"%1\" width=\"48\" height=\"48\"/></div>" )
- .tqarg( imgToDataUrl( xf.toImage( xfhead ), "PNG" ) );
+ .arg( imgToDataUrl( xf.toImage( xfhead ), "PNG" ) );
}
// fancy header style
@@ -660,7 +660,7 @@ void ArticleWidget::displayHeader()
int refCnt = refs->count(), i = 1;
TQCString id = refs->first();
id = id.mid( 1, id.length() - 2 ); // remove <>
- html += TQString( "<b>%1</b>" ).tqarg( i18n("References:") );
+ html += TQString( "<b>%1</b>" ).arg( i18n("References:") );
while ( i <= refCnt ) {
html += " <a href=\"news:" + TQString::fromLatin1( id ) + "\">" + TQString::number( i ) + "</a>";
@@ -748,7 +748,7 @@ TQString ArticleWidget::displaySigHeader( Kpgp::Block* block )
TQString message;
if ( signer.isEmpty() ) {
message = i18n( "Message was signed with unknown key 0x%1." )
- .tqarg( TQString(signerKey) );
+ .arg( TQString(signerKey) );
message += "<br/>";
message += i18n( "The validity of the signature cannot be verified." );
signClass = "signWarn";
@@ -769,10 +769,10 @@ TQString ArticleWidget::displaySigHeader( Kpgp::Block* block )
if( !signerKey.isEmpty() )
message += i18n( "Message was signed by %1 (Key ID: 0x%2)." )
- .tqarg( signer )
- .tqarg( TQString(signerKey) );
+ .arg( signer )
+ .arg( TQString(signerKey) );
else
- message += i18n( "Message was signed by %1." ).tqarg( signer );
+ message += i18n( "Message was signed by %1." ).arg( signer );
message += "<br/>";
if( block->goodSignature() ) {
@@ -916,7 +916,7 @@ TQString ArticleWidget::imgToDataUrl( const TQImage &image, const char* fmt )
buffer.open( IO_WriteOnly );
image.save( &buffer, fmt );
return TQString::fromLatin1("data:image/%1;base64,%2")
- .tqarg( fmt, TQString(KCodecs::base64Encode( ba )) );
+ .arg( fmt, TQString(KCodecs::base64Encode( ba )) );
}
@@ -1030,7 +1030,7 @@ void ArticleWidget::processJob( KNJobData * job )
if ( !job->canceled() ) {
if ( !job->success() )
KMessageBox::error( this, i18n("An error occurred while downloading the article source:\n")
- .tqarg( job->errorString() ) );
+ .arg( job->errorString() ) );
else
new KNSourceViewWindow( a->head() + "\n" + a->body() );
}
diff --git a/knode/knaccountmanager.cpp b/knode/knaccountmanager.cpp
index e8d1ef38..2dc8c931 100644
--- a/knode/knaccountmanager.cpp
+++ b/knode/knaccountmanager.cpp
@@ -127,12 +127,12 @@ bool KNAccountManager::newAccount(KNNntpAccount *a)
TQStringList entries(d.entryList("nntp.*", TQDir::Dirs));
int id = 1;
- while (entries.findIndex(TQString("nntp.%1").tqarg(id))!=-1)
+ while (entries.findIndex(TQString("nntp.%1").arg(id))!=-1)
++id;
a->setId(id);
- dir = locateLocal("data",TQString("knode/nntp.%1/").tqarg(a->id()));
+ dir = locateLocal("data",TQString("knode/nntp.%1/").arg(a->id()));
if (!dir.isNull()) {
mAccounts.append(a);
emit(accountAdded(a));
@@ -177,7 +177,7 @@ bool KNAccountManager::removeAccount(KNNntpAccount *a)
}
}
dir.cdUp(); // directory should now be empty, deleting it
- dir.rmdir(TQString("nntp.%1/").tqarg(a->id()));
+ dir.rmdir(TQString("nntp.%1/").arg(a->id()));
}
if(c_urrentAccount==a) setCurrentAccount(0);
diff --git a/knode/knarticle.cpp b/knode/knarticle.cpp
index e253d2ef..fe475b1b 100644
--- a/knode/knarticle.cpp
+++ b/knode/knarticle.cpp
@@ -209,7 +209,7 @@ void KNRemoteArticle::updateListItem()
i_tem->setExpandable( (threadMode() && hasVisibleFollowUps()) );
- i_tem->tqrepaint(); //force tqrepaint
+ i_tem->repaint(); //force repaint
}
diff --git a/knode/knarticlefactory.cpp b/knode/knarticlefactory.cpp
index 3a2a414e..c260208e 100644
--- a/knode/knarticlefactory.cpp
+++ b/knode/knarticlefactory.cpp
@@ -306,7 +306,7 @@ void KNArticleFactory::createForward(KNArticle *a)
//--------------------------- <Body> -----------------------------
- TQString fwd = TQString("\n--------------- %1\n\n").tqarg(i18n("Forwarded message (begin)"));
+ TQString fwd = TQString("\n--------------- %1\n\n").arg(i18n("Forwarded message (begin)"));
fwd+=( i18n("Subject") + ": " + a->subject()->asUnicodeString() + "\n" );
fwd+=( i18n("From") + ": " + a->from()->asUnicodeString() + "\n" );
@@ -321,7 +321,7 @@ void KNArticleFactory::createForward(KNArticle *a)
fwd += (*it) + "\n";
}
- fwd += TQString("\n--------------- %1\n").tqarg(i18n("Forwarded message (end)"));
+ fwd += TQString("\n--------------- %1\n").arg(i18n("Forwarded message (end)"));
//--------------------------- </Body> ----------------------------
@@ -601,7 +601,7 @@ void KNArticleFactory::edit(KNLocalArticle *a)
KMessageBox::information(knGlobals.topWidget,
i18n("<qt>The signature generator program produced the "
"following output:<br><br>%1</qt>")
- .tqarg(id->getSigGeneratorStdErr()));
+ .arg(id->getSigGeneratorStdErr()));
mCompList.append( com );
connect(com, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
@@ -895,7 +895,7 @@ KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, TQString &sig, T
KMessageBox::information(knGlobals.topWidget,
i18n("<qt>The signature generator program produced the "
"following output:<br><br>%1</qt>")
- .tqarg(id->getSigGeneratorStdErr()));
+ .arg(id->getSigGeneratorStdErr()));
}
else
sig=TQString();
@@ -1070,8 +1070,8 @@ KNSendErrorDialog::KNSendErrorDialog()
TQVBox *page = makeVBoxMainWidget();
- new TQLabel(TQString("<b>%1</b><br>%2").tqarg(i18n("Errors occurred while sending these articles:"))
- .tqarg(i18n("The unsent articles are stored in the \"Outbox\" folder.")), page);
+ new TQLabel(TQString("<b>%1</b><br>%2").arg(i18n("Errors occurred while sending these articles:"))
+ .arg(i18n("The unsent articles are stored in the \"Outbox\" folder.")), page);
j_obs=new KNDialogListBox(true, page);
e_rror=new TQLabel(TQString(), page);
diff --git a/knode/knarticlefilter.cpp b/knode/knarticlefilter.cpp
index 8a7236c4..65acb7c0 100644
--- a/knode/knarticlefilter.cpp
+++ b/knode/knarticlefilter.cpp
@@ -74,7 +74,7 @@ KNArticleFilter::~KNArticleFilter()
bool KNArticleFilter::loadInfo()
{
if (i_d!=-1) {
- TQString fname(locate("data",TQString( "knode/filters/%1.fltr" ).tqarg(i_d) ) );
+ TQString fname(locate("data",TQString( "knode/filters/%1.fltr" ).arg(i_d) ) );
if (fname.isNull())
return false;
@@ -94,7 +94,7 @@ bool KNArticleFilter::loadInfo()
void KNArticleFilter::load()
{
- TQString fname(locate("data",TQString( "knode/filters/%1.fltr").tqarg(i_d) ) );
+ TQString fname(locate("data",TQString( "knode/filters/%1.fltr").arg(i_d) ) );
if (fname.isNull())
return;
@@ -141,7 +141,7 @@ void KNArticleFilter::save()
KNHelper::displayInternalFileError();
return;
}
- KSimpleConfig conf(dir+TQString("%1.fltr").tqarg(i_d));
+ KSimpleConfig conf(dir+TQString("%1.fltr").arg(i_d));
conf.setGroup("GENERAL");
conf.writeEntry("name", TQString(n_ame));
diff --git a/knode/knarticlemanager.cpp b/knode/knarticlemanager.cpp
index 7673eabf..f5a59c57 100644
--- a/knode/knarticlemanager.cpp
+++ b/knode/knarticlemanager.cpp
@@ -186,7 +186,7 @@ void KNArticleManager::showHdrs(bool clear)
v_iew->clear();
knGlobals.top->setCursorBusy(true);
- knGlobals.seStatusMsg(i18n(" Creating list..."));
+ knGlobals.setStatusMsg(i18n(" Creating list..."));
knGlobals.top->secureProcessEvents();
if(g_roup) {
@@ -324,7 +324,7 @@ void KNArticleManager::showHdrs(bool clear)
knGlobals.top->articleViewer()->setArticle( 0 );
}
- knGlobals.seStatusMsg(TQString());
+ knGlobals.setStatusMsg(TQString());
updateStatusString();
knGlobals.top->setCursorBusy(false);
}
@@ -991,25 +991,25 @@ void KNArticleManager::updateStatusString()
if (g_roup->status()==KNGroup::moderated)
name += i18n(" (moderated)");
- knGlobals.seStatusMsg(i18n(" %1: %2 new , %3 displayed")
- .tqarg(name).tqarg(g_roup->newCount()).tqarg(displCnt),SB_GROUP);
+ knGlobals.setStatusMsg(i18n(" %1: %2 new , %3 displayed")
+ .arg(name).arg(g_roup->newCount()).arg(displCnt),SB_GROUP);
if(f_ilter)
- knGlobals.seStatusMsg(i18n(" Filter: %1").tqarg(f_ilter->translatedName()), SB_FILTER);
+ knGlobals.setStatusMsg(i18n(" Filter: %1").arg(f_ilter->translatedName()), SB_FILTER);
else
- knGlobals.seStatusMsg(TQString(), SB_FILTER);
+ knGlobals.setStatusMsg(TQString(), SB_FILTER);
}
else if(f_older) {
if(f_ilter)
displCnt=f_ilter->count();
else
displCnt=f_older->count();
- knGlobals.seStatusMsg(i18n(" %1: %2 displayed")
- .tqarg(f_older->name()).tqarg(displCnt), SB_GROUP);
- knGlobals.seStatusMsg(TQString(), SB_FILTER);
+ knGlobals.setStatusMsg(i18n(" %1: %2 displayed")
+ .arg(f_older->name()).arg(displCnt), SB_GROUP);
+ knGlobals.setStatusMsg(TQString(), SB_FILTER);
} else {
- knGlobals.seStatusMsg(TQString(), SB_GROUP);
- knGlobals.seStatusMsg(TQString(), SB_FILTER);
+ knGlobals.setStatusMsg(TQString(), SB_GROUP);
+ knGlobals.setStatusMsg(TQString(), SB_FILTER);
}
}
diff --git a/knode/kncleanup.cpp b/knode/kncleanup.cpp
index 28993e7c..3e79b4a6 100644
--- a/knode/kncleanup.cpp
+++ b/knode/kncleanup.cpp
@@ -56,13 +56,13 @@ void KNCleanUp::start()
for ( TQValueList<KNArticleCollection*>::Iterator it = mColList.begin(); it != mColList.end(); ++it ) {
if ( (*it)->type() == KNCollection::CTgroup ) {
- d_lg->showMessage( i18n("Deleting expired articles in <b>%1</b>").tqarg( (*it)->name() ) );
+ d_lg->showMessage( i18n("Deleting expired articles in <b>%1</b>").arg( (*it)->name() ) );
kapp->processEvents();
expireGroup( static_cast<KNGroup*>( (*it) ) );
d_lg->doProgress();
}
else if ( (*it)->type() == KNCollection::CTfolder ) {
- d_lg->showMessage( i18n("Compacting folder <b>%1</b>").tqarg( (*it)->name() ) );
+ d_lg->showMessage( i18n("Compacting folder <b>%1</b>").arg( (*it)->name() ) );
kapp->processEvents();
compactFolder( static_cast<KNFolder*>( (*it) ) );
d_lg->doProgress();
@@ -187,7 +187,7 @@ void KNCleanUp::expireGroup( KNGroup *g, bool showResult )
if(showResult)
KMessageBox::information(knGlobals.topWidget,
- i18n("<b>%1</b><br>expired: %2<br>left: %3").tqarg(g->groupname()).tqarg(delCnt).tqarg(leftCnt));
+ i18n("<b>%1</b><br>expired: %2<br>left: %3").arg(g->groupname()).arg(delCnt).arg(leftCnt));
}
diff --git a/knode/kncomposer.cpp b/knode/kncomposer.cpp
index d21f9b7f..c2523d13 100644
--- a/knode/kncomposer.cpp
+++ b/knode/kncomposer.cpp
@@ -969,7 +969,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
ts.setCodec(codec);
if (box)
- temp = TQString::fromLatin1(",----[ %1 ]\n").tqarg(boxTitle);
+ temp = TQString::fromLatin1(",----[ %1 ]\n").arg(boxTitle);
if (box && (v_iew->e_dit->wordWrap()!=TQMultiLineEdit::NoWrap)) {
int wrapAt = v_iew->e_dit->wrapColumnOrWidth();
@@ -1374,18 +1374,18 @@ void KNComposer::slotUpdateStatusBar()
else
overwriteDesc = i18n(" INS ");
- statusBar()->changeItem(i18n(" Type: %1 ").tqarg(typeDesc), 1);
- statusBar()->changeItem(i18n(" Charset: %1 ").tqarg(TQString(c_harset)), 2);
+ statusBar()->changeItem(i18n(" Type: %1 ").arg(typeDesc), 1);
+ statusBar()->changeItem(i18n(" Charset: %1 ").arg(TQString(c_harset)), 2);
statusBar()->changeItem(overwriteDesc, 3);
- statusBar()->changeItem(i18n(" Column: %1 ").tqarg(v_iew->e_dit->currentColumn() + 1), 4);
- statusBar()->changeItem(i18n(" Line: %1 ").tqarg(v_iew->e_dit->currentLine() + 1), 5);
+ statusBar()->changeItem(i18n(" Column: %1 ").arg(v_iew->e_dit->currentColumn() + 1), 4);
+ statusBar()->changeItem(i18n(" Line: %1 ").arg(v_iew->e_dit->currentLine() + 1), 5);
}
void KNComposer::slotUpdateCursorPos()
{
- statusBar()->changeItem(i18n(" Column: %1 ").tqarg(v_iew->e_dit->currentColumn() + 1), 4);
- statusBar()->changeItem(i18n(" Line: %1 ").tqarg(v_iew->e_dit->currentLine() + 1), 5);
+ statusBar()->changeItem(i18n(" Column: %1 ").arg(v_iew->e_dit->currentColumn() + 1), 4);
+ statusBar()->changeItem(i18n(" Line: %1 ").arg(v_iew->e_dit->currentLine() + 1), 5);
}
@@ -2233,7 +2233,7 @@ void KNComposer::Editor::slotAddBox()
} else {
int l = currentLine();
int c = currentColumn();
- TQString s = TQString::fromLatin1(",----[ ]\n| %1\n`----").tqarg(textLine(l));
+ TQString s = TQString::fromLatin1(",----[ ]\n| %1\n`----").arg(textLine(l));
insertLine(s,l);
removeLine(l+3);
setCursorPosition(l+1,c+2);
@@ -2297,7 +2297,7 @@ void KNComposer::Editor::slotRemoveBox()
setCursorPosition(l,c-2);
setAutoUpdate(true);
- tqrepaint(false);
+ repaint(false);
}
}
@@ -2560,7 +2560,7 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
fileL->addRowSpacing(0, fontMetrics().lineSpacing()-9);
fileL->addWidget(new TQLabel(i18n("Name:"), fileGB) ,1,0);
- fileL->addWidget(new TQLabel(TQString("<b>%1</b>").tqarg(a->name()), fileGB), 1,1, TQt::AlignLeft);
+ fileL->addWidget(new TQLabel(TQString("<b>%1</b>").arg(a->name()), fileGB), 1,1, TQt::AlignLeft);
fileL->addWidget(new TQLabel(i18n("Size:"), fileGB), 2,0);
fileL->addWidget(new TQLabel(a->contentSize(), fileGB), 2,1, TQt::AlignLeft);
diff --git a/knode/knconfigwidgets.cpp b/knode/knconfigwidgets.cpp
index 99f25d78..aa93af98 100644
--- a/knode/knconfigwidgets.cpp
+++ b/knode/knconfigwidgets.cpp
@@ -395,8 +395,8 @@ void KNConfig::NntpAccountListWidget::slotSelectionChanged()
LBoxItem *it = static_cast<LBoxItem*>(l_box->item(curr));
if(it) {
- s_erverInfo->setText(i18n("Server: %1").tqarg(it->account->server()));
- p_ortInfo->setText(i18n("Port: %1").tqarg(it->account->port()));
+ s_erverInfo->setText(i18n("Server: %1").arg(it->account->server()));
+ p_ortInfo->setText(i18n("Port: %1").arg(it->account->port()));
}
else {
s_erverInfo->setText(i18n("Server: "));
@@ -461,7 +461,7 @@ void KNConfig::NntpAccountListWidget::slotSubBtnClicked()
KNConfig::NntpAccountConfDialog::NntpAccountConfDialog(KNNntpAccount *a, TQWidget *p, const char *n)
- : KDialogBase(Tabbed, (a->id()!=-1)? i18n("Properties of %1").tqarg(a->name()):i18n("New Account"),
+ : KDialogBase(Tabbed, (a->id()!=-1)? i18n("Properties of %1").arg(a->name()):i18n("New Account"),
Ok|Cancel|Help, Ok, p, n),
a_ccount(a)
{
@@ -773,7 +773,7 @@ int KNConfig::AppearanceWidget::ColorListItem::width(const TQListBox *lb ) const
KNConfig::AppearanceWidget::FontListItem::FontListItem( const TQString &name, const TQFont &font )
: TQListBoxText(name), f_ont(font)
{
- fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
+ fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
}
@@ -785,7 +785,7 @@ KNConfig::AppearanceWidget::FontListItem::~FontListItem()
void KNConfig::AppearanceWidget::FontListItem::setFont(const TQFont &font)
{
f_ont = font;
- fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
+ fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
}
@@ -896,7 +896,7 @@ void KNConfig::AppearanceWidget::defaults()
colorItem->setColor(d_ata->defaultColor(i));
}
c_List->triggerUpdate(true);
- c_List->tqrepaint(true);
+ c_List->repaint(true);
// default fonts
FontListItem *fontItem;
@@ -2158,7 +2158,7 @@ TQString KNConfig::XHeaderConfDialog::result()
TQString value = v_alue->text();
// just in case someone pastes a newline
value.replace( '\n', ' ' );
- return TQString( "X-%1: %2" ).tqarg( n_ame->text() ).tqarg( value );
+ return TQString( "X-%1: %2" ).arg( n_ame->text() ).arg( value );
}
diff --git a/knode/knconvert.cpp b/knode/knconvert.cpp
index 2db7b6f3..8fdb4890 100644
--- a/knode/knconvert.cpp
+++ b/knode/knconvert.cpp
@@ -73,7 +73,7 @@ KNConvert::KNConvert(const TQString &version)
Unfortunately this version uses a different format for some data-files, so \
in order to keep your existing data it is necessary to convert it first. This is \
now done automatically by KNode. If you want to, a backup of your existing data \
-will be created before the conversion starts.").tqarg(KNODE_VERSION), w_1);
+will be created before the conversion starts.").arg(KNODE_VERSION), w_1);
w1L->addMultiCellWidget(l1, 0,0, 0,2);
c_reateBkup=new TQCheckBox(i18n("Create backup of old data"), w_1);
@@ -224,7 +224,7 @@ void KNConvert::slotTarExited(KProcess *proc)
delete t_ar;
t_ar = 0;
if(success)
- l_og.append(i18n("created backup of the old data-files in %1").tqarg(b_ackupPath->text()));
+ l_og.append(i18n("created backup of the old data-files in %1").arg(b_ackupPath->text()));
else
l_og.append(i18n("backup failed."));
@@ -402,7 +402,7 @@ int KNConvert::Converter04::convertFolder(TQString srcPrefix, TQString dstPrefix
TQCString buff(size+10);
srcMBox.at(oldIdx.so);
int readBytes=srcMBox.readBlock(buff.data(), size);
- buff.tqat(readBytes)='\0'; //terminate string;
+ buff.at(readBytes)='\0'; //terminate string;
//remove "X-KNode-Overview"
int pos=buff.find('\n');
diff --git a/knode/knfilterdialog.cpp b/knode/knfilterdialog.cpp
index 729ec495..e9ebf66e 100644
--- a/knode/knfilterdialog.cpp
+++ b/knode/knfilterdialog.cpp
@@ -31,7 +31,7 @@
KNFilterDialog::KNFilterDialog(KNArticleFilter *f, TQWidget *parent, const char *name)
- : KDialogBase(Plain, (f->id()==-1)? i18n("New Filter"):i18n("Properties of %1").tqarg(f->name()),
+ : KDialogBase(Plain, (f->id()==-1)? i18n("New Filter"):i18n("Properties of %1").arg(f->name()),
Ok|Cancel|Help, Ok, parent, name),
fltr(f)
{
diff --git a/knode/knfolder.cpp b/knode/knfolder.cpp
index 58ac7d0f..5be7535c 100644
--- a/knode/knfolder.cpp
+++ b/knode/knfolder.cpp
@@ -44,7 +44,7 @@ KNFolder::KNFolder()
KNFolder::KNFolder(int id, const TQString &name, KNFolder *parent)
: KNArticleCollection(parent), i_d(id), i_ndexDirty(false), w_asOpen(true)
{
- TQString fname=path()+TQString("custom_%1").tqarg(i_d);
+ TQString fname=path()+TQString("custom_%1").arg(i_d);
n_ame = name;
m_boxFile.setName(fname+".mbox");
@@ -63,7 +63,7 @@ KNFolder::KNFolder(int id, const TQString &name, KNFolder *parent)
KNFolder::KNFolder(int id, const TQString &name, const TQString &prefix, KNFolder *parent)
: KNArticleCollection(parent), i_d(id), i_ndexDirty(false), w_asOpen(true)
{
- TQString fname=path()+TQString("%1_%2").tqarg(prefix).tqarg(i_d);
+ TQString fname=path()+TQString("%1_%2").arg(prefix).arg(i_d);
n_ame = name;
m_boxFile.setName(fname+".mbox");
@@ -193,7 +193,7 @@ bool KNFolder::loadHdrs()
int pos1=0, pos2=0, cnt=0, byteCount;
knGlobals.top->setCursorBusy(true);
- knGlobals.seStatusMsg(i18n(" Loading folder..."));
+ knGlobals.setStatusMsg(i18n(" Loading folder..."));
knGlobals.top->secureProcessEvents();
while(!i_ndexFile.atEnd()) {
@@ -284,7 +284,7 @@ bool KNFolder::loadHdrs()
clear();
closeFiles();
- knGlobals.seStatusMsg(TQString());
+ knGlobals.setStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
return false;
}
@@ -297,7 +297,7 @@ bool KNFolder::loadHdrs()
c_ount=cnt;
updateListItem();
- knGlobals.seStatusMsg(TQString());
+ knGlobals.setStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
return true;
@@ -356,7 +356,7 @@ bool KNFolder::loadArticle(KNLocalArticle *a)
}
//set content
- buff.tqat(readBytes)='\0'; //terminate string
+ buff.at(readBytes)='\0'; //terminate string
a->setContent(buff);
a->parse();
diff --git a/knode/knfoldermanager.cpp b/knode/knfoldermanager.cpp
index 7041f456..661e1b6c 100644
--- a/knode/knfoldermanager.cpp
+++ b/knode/knfoldermanager.cpp
@@ -294,7 +294,7 @@ void KNFolderManager::importFromMBox(KNFolder *f)
if (file) {
knGlobals.top->setCursorBusy(true);
- knGlobals.seStatusMsg(i18n(" Importing articles..."));
+ knGlobals.setStatusMsg(i18n(" Importing articles..."));
knGlobals.top->secureProcessEvents();
if (!file->atEnd()) { // search for the first article...
@@ -326,7 +326,7 @@ void KNFolderManager::importFromMBox(KNFolder *f)
int readBytes=file->readBlock(buff.data(), size);
if (readBytes != -1) {
- buff.tqat(readBytes)='\0'; //terminate string
+ buff.at(readBytes)='\0'; //terminate string
art = new KNLocalArticle(0);
art->setEditDisabled(true);
art->setContent(buff);
@@ -345,7 +345,7 @@ void KNFolderManager::importFromMBox(KNFolder *f)
int readBytes=file->readBlock(buff.data(), size);
if (readBytes != -1) {
- buff.tqat(readBytes)='\0'; //terminate string
+ buff.at(readBytes)='\0'; //terminate string
art = new KNLocalArticle(0);
art->setEditDisabled(true);
art->setContent(buff);
@@ -360,13 +360,13 @@ void KNFolderManager::importFromMBox(KNFolder *f)
}
}
- knGlobals.seStatusMsg(i18n(" Storing articles..."));
+ knGlobals.setStatusMsg(i18n(" Storing articles..."));
knGlobals.top->secureProcessEvents();
if (!list.isEmpty())
knGlobals.articleManager()->moveIntoFolder(list, f);
- knGlobals.seStatusMsg(TQString());
+ knGlobals.setStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
}
@@ -391,7 +391,7 @@ void KNFolderManager::exportToMBox(KNFolder *f)
if (file) {
knGlobals.top->setCursorBusy(true);
- knGlobals.seStatusMsg(i18n(" Exporting articles..."));
+ knGlobals.setStatusMsg(i18n(" Exporting articles..."));
knGlobals.top->secureProcessEvents();
TQTextStream ts(file);
@@ -415,7 +415,7 @@ void KNFolderManager::exportToMBox(KNFolder *f)
knGlobals.top->secureProcessEvents();
}
- knGlobals.seStatusMsg(TQString());
+ knGlobals.setStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
}
}
diff --git a/knode/knglobals.cpp b/knode/knglobals.cpp
index 7a6f0c22..eaf026e8 100644
--- a/knode/knglobals.cpp
+++ b/knode/knglobals.cpp
@@ -134,8 +134,8 @@ KNMemoryManager* KNGlobals::memoryManager()
}
-void KNGlobals::seStatusMsg(const TQString &text, int id)
+void KNGlobals::setStatusMsg(const TQString &text, int id)
{
if(top)
- top->seStatusMsg(text, id);
+ top->setStatusMsg(text, id);
}
diff --git a/knode/kngroup.cpp b/knode/kngroup.cpp
index c0ba082b..c42aab07 100644
--- a/knode/kngroup.cpp
+++ b/knode/kngroup.cpp
@@ -71,7 +71,7 @@ void KNGroup::updateListItem()
if(!l_istItem) return;
l_istItem->setTotalCount( c_ount );
l_istItem->setUnreadCount( c_ount - r_eadCount - i_gnoreCount );
- l_istItem->tqrepaint();
+ l_istItem->repaint();
}
@@ -904,7 +904,7 @@ void KNGroup::scoreArticles(bool onlynew)
kdDebug(5003) << "scoring " << newCount() << " articles" << endl;
kdDebug(5003) << "(total " << length() << " article in group)" << endl;
knGlobals.top->setCursorBusy(true);
- knGlobals.seStatusMsg(i18n(" Scoring..."));
+ knGlobals.setStatusMsg(i18n(" Scoring..."));
int defScore;
KScoringManager *sm = knGlobals.scoringManager();
@@ -936,7 +936,7 @@ void KNGroup::scoreArticles(bool onlynew)
incReadCount();
}
- knGlobals.seStatusMsg(TQString());
+ knGlobals.setStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
//kdDebug(5003) << KNScorableArticle::notifyC->collection() << endl;
@@ -951,7 +951,7 @@ void KNGroup::reorganize()
kdDebug(5003) << "KNGroup::reorganize()" << endl;
knGlobals.top->setCursorBusy(true);
- knGlobals.seStatusMsg(i18n(" Reorganizing headers..."));
+ knGlobals.setStatusMsg(i18n(" Reorganizing headers..."));
for(int idx=0; idx<length(); idx++) {
KNRemoteArticle *a = at(idx);
@@ -964,8 +964,8 @@ void KNGroup::reorganize()
buildThreads(length());
saveStaticData(length(), true);
saveDynamicData(length(), true);
- knGlobals.top->headerView()->tqrepaint();
- knGlobals.seStatusMsg(TQString());
+ knGlobals.top->headerView()->repaint();
+ knGlobals.setStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
}
@@ -1052,7 +1052,7 @@ TQString KNGroup::prepareForExecution()
if (knGlobals.groupManager()->loadHeaders(this))
return TQString();
else
- return i18n("Cannot load saved headers: %1").tqarg(groupname());
+ return i18n("Cannot load saved headers: %1").arg(groupname());
}
//***************************************************************************
diff --git a/knode/kngroup.h b/knode/kngroup.h
index 76a9d0dd..fef5c6d6 100644
--- a/knode/kngroup.h
+++ b/knode/kngroup.h
@@ -124,7 +124,7 @@ class KNGroup : public KNArticleCollection , public KNJobItem {
KNConfig::Identity* identity()const { return i_dentity; }
void setIdentity(KNConfig::Identity *i) { i_dentity=i; }
Status status()const { return s_tatus; }
- void seStatus(Status s) { s_tatus=s; }
+ void setStatus(Status s) { s_tatus=s; }
void showProperties();
// cleanup configuration
diff --git a/knode/kngroupbrowser.cpp b/knode/kngroupbrowser.cpp
index a3bcb89f..3aa9677b 100644
--- a/knode/kngroupbrowser.cpp
+++ b/knode/kngroupbrowser.cpp
@@ -358,7 +358,7 @@ void KNGroupBrowser::slotFilter(const TQString &txt)
lastFilter = filtertxt;
incrementalFilter = !isRegexp;
- leftLabel->setText(i18n("Groups on %1: (%2 displayed)").tqarg(a_ccount->name()).tqarg(matchList->count()));
+ leftLabel->setText(i18n("Groups on %1: (%2 displayed)").arg(a_ccount->name()).arg(matchList->count()));
arrowBtn1->setEnabled(false);
arrowBtn2->setEnabled(false);
diff --git a/knode/kngroupmanager.cpp b/knode/kngroupmanager.cpp
index ea24f793..271a689d 100644
--- a/knode/kngroupmanager.cpp
+++ b/knode/kngroupmanager.cpp
@@ -435,7 +435,7 @@ void KNGroupManager::subscribeGroup(const KNGroupInfo *gi, KNNntpAccount *a)
grp=new KNGroup(a);
grp->setGroupname(gi->name);
grp->setDescription(gi->description);
- grp->seStatus(gi->status);
+ grp->setStatus(gi->status);
grp->saveInfo();
mGroupList.append( grp );
emit groupAdded(grp);
@@ -449,7 +449,7 @@ bool KNGroupManager::unsubscribeGroup(KNGroup *g)
if(!g) return false;
if((g->isLocked()) || (g->lockedArticles()>0)) {
- KMessageBox::sorry(knGlobals.topWidget, i18n("The group \"%1\" is being updated currently.\nIt is not possible to unsubscribe from it at the moment.").tqarg(g->groupname()));
+ KMessageBox::sorry(knGlobals.topWidget, i18n("The group \"%1\" is being updated currently.\nIt is not possible to unsubscribe from it at the moment.").arg(g->groupname()));
return false;
}
@@ -596,7 +596,7 @@ void KNGroupManager::processJob(KNJobData *j)
for ( KNGroupInfo* inf = d->groups->first(); inf; inf = d->groups->next() )
if ( inf->name == (*it)->groupname() ) {
(*it)->setDescription( inf->description );
- (*it)->seStatus( inf->status );
+ (*it)->setStatus( inf->status );
break;
}
}
diff --git a/knode/kngrouppropdlg.cpp b/knode/kngrouppropdlg.cpp
index a49e03a9..3ad2fee7 100644
--- a/knode/kngrouppropdlg.cpp
+++ b/knode/kngrouppropdlg.cpp
@@ -30,7 +30,7 @@
KNGroupPropDlg::KNGroupPropDlg(KNGroup *group, TQWidget *parent, const char *name )
- : KDialogBase(Tabbed, i18n("Properties of %1").tqarg(group->groupname()),
+ : KDialogBase(Tabbed, i18n("Properties of %1").arg(group->groupname()),
Ok|Cancel|Help, Ok, parent, name),
g_rp(group), n_ickChanged(false)
{
diff --git a/knode/knhdrviewitem.cpp b/knode/knhdrviewitem.cpp
index cf2713b8..6330b89a 100644
--- a/knode/knhdrviewitem.cpp
+++ b/knode/knhdrviewitem.cpp
@@ -114,7 +114,7 @@ int KNHdrViewItem::compare( TQListViewItem *i, int col, bool ) const
}
-void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
+void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
{
int xText = 0, xPM = 3, yPM = 0;
TQColor base;
@@ -159,7 +159,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
TQString t2;
TQFont f2;
if (countUnreadInThread() > 0 && column == paintInfo->subCol && !isOpen()) {
- t2 = TQString( " (%1)" ).tqarg( countUnreadInThread() );
+ t2 = TQString( " (%1)" ).arg( countUnreadInThread() );
f2 = p->font();
f2.setBold( true );
cntWidth = TQFontMetrics( f2 ).width( t2, -1 );
@@ -172,7 +172,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
else
mShowToolTip[column] = false;
- p->drawText( xText, 0, width - xText - 5, height(), tqalignment | AlignVCenter, t );
+ p->drawText( xText, 0, width - xText - 5, height(), alignment | AlignVCenter, t );
if (cntWidth) {
TQFont orig = p->font();
p->setFont( f2 );
@@ -183,7 +183,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
pen.setColor( cg.link() );
}
p->setPen( pen );
- p->drawText( xText + TQFontMetrics( orig ).width( t, -1 ), 0, width - xText - 5, height(), tqalignment | AlignVCenter, t2 );
+ p->drawText( xText + TQFontMetrics( orig ).width( t, -1 ), 0, width - xText - 5, height(), alignment | AlignVCenter, t2 );
}
}
}
diff --git a/knode/knhdrviewitem.h b/knode/knhdrviewitem.h
index 163a4507..476c6d53 100644
--- a/knode/knhdrviewitem.h
+++ b/knode/knhdrviewitem.h
@@ -33,7 +33,7 @@ class KNHdrViewItem : public KListViewItem {
virtual int compare(TQListViewItem *i, int col, bool ascending) const;
- void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment);
int width(const TQFontMetrics &fm, const TQListView *lv, int column);
virtual TQString text( int col ) const;
diff --git a/knode/knjobdata.cpp b/knode/knjobdata.cpp
index 81c2595e..fefd96b1 100644
--- a/knode/knjobdata.cpp
+++ b/knode/knjobdata.cpp
@@ -95,7 +95,7 @@ void KNJobData::cancel()
mJob = 0;
}
if ( mProgressItem ) {
- mProgressItem->seStatus( "Canceled" );
+ mProgressItem->setStatus( "Canceled" );
mProgressItem->setComplete();
mProgressItem = 0;
}
@@ -140,7 +140,7 @@ void KNJobData::slotJobPercent( KIO::Job*, unsigned long percent )
void KNJobData::slotJobInfoMessage( KIO::Job*, const TQString &msg )
{
kdDebug(5003) << k_funcinfo << "Status: " << msg << endl;
- seStatus( msg );
+ setStatus( msg );
}
diff --git a/knode/knjobdata.h b/knode/knjobdata.h
index 7f14dc7b..5d9352ad 100644
--- a/knode/knjobdata.h
+++ b/knode/knjobdata.h
@@ -115,7 +115,7 @@ class KNJobData : public TQObject
void createProgressItem();
// safe forwards to the progress item
- void seStatus( const TQString &msg ) { if ( mProgressItem ) mProgressItem->seStatus( msg ); }
+ void setStatus( const TQString &msg ) { if ( mProgressItem ) mProgressItem->setStatus( msg ); }
void setProgress( unsigned int progress ) { if ( mProgressItem ) mProgressItem->setProgress( progress ); }
void setComplete() { if ( mProgressItem ) { mProgressItem->setComplete(); mProgressItem = 0; } }
diff --git a/knode/knmainwidget.cpp b/knode/knmainwidget.cpp
index 57e6f0be..701bee28 100644
--- a/knode/knmainwidget.cpp
+++ b/knode/knmainwidget.cpp
@@ -253,7 +253,7 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
c_olView->setFocus();
- seStatusMsg();
+ setStatusMsg();
if( firstStart() ) { // open the config dialog on the first start
show(); // the settings dialog must appear in front of the main window!
@@ -315,7 +315,7 @@ void KNMainWidget::iniStatusBar()
//================================== GUI =================================
-void KNMainWidget::seStatusMsg(const TQString& text, int id)
+void KNMainWidget::setStatusMsg(const TQString& text, int id)
{
KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
KStatusBar *bar = mainWin ? mainWin->statusBar() : 0;
@@ -324,13 +324,13 @@ void KNMainWidget::seStatusMsg(const TQString& text, int id)
bar->clear();
if (text.isEmpty() && (id==SB_MAIN)) {
if (knGlobals.netAccess()->currentMsg().isEmpty())
- BroadcastStatus::instance()->seStatusMsg(i18n(" Ready"));
+ BroadcastStatus::instance()->setStatusMsg(i18n(" Ready"));
else
- BroadcastStatus::instance()->seStatusMsg(knGlobals.netAccess()->currentMsg());
+ BroadcastStatus::instance()->setStatusMsg(knGlobals.netAccess()->currentMsg());
} else {
switch(id) {
case SB_MAIN:
- BroadcastStatus::instance()->seStatusMsg(text); break;
+ BroadcastStatus::instance()->setStatusMsg(text); break;
case SB_GROUP:
s_tatusGroup->setText(text); break;
case SB_FILTER:
@@ -340,7 +340,7 @@ void KNMainWidget::seStatusMsg(const TQString& text, int id)
}
-void KNMainWidget::seStatusHelpMsg(const TQString& text)
+void KNMainWidget::setStatusHelpMsg(const TQString& text)
{
KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
KStatusBar *bar = mainWin ? mainWin->statusBar() : 0;
@@ -775,7 +775,7 @@ bool KNMainWidget::firstStart()
emailConf.setGroup("Defaults");
TQString group = emailConf.readEntry("Profile","Default");
- emailConf.setGroup(TQString("PROFILE_%1").tqarg(group));
+ emailConf.setGroup(TQString("PROFILE_%1").arg(group));
KNConfig::Identity *id=knGlobals.configManager()->identity();
id->setName(emailConf.readEntry("FullName"));
id->setEmail(emailConf.readEntry("EmailAddress").latin1());
@@ -1511,7 +1511,7 @@ void KNMainWidget::slotGrpUnsubscribe()
kdDebug(5003) << "KNMainWidget::slotGrpUnsubscribe()" << endl;
if(g_rpManager->currentGroup()) {
if(KMessageBox::Yes==KMessageBox::questionYesNo(knGlobals.topWidget,
- i18n("Do you really want to unsubscribe from %1?").tqarg(g_rpManager->currentGroup()->groupname()), TQString(), i18n("Unsubscribe"), KStdGuiItem::cancel()))
+ i18n("Do you really want to unsubscribe from %1?").arg(g_rpManager->currentGroup()->groupname()), TQString(), i18n("Unsubscribe"), KStdGuiItem::cancel()))
if (g_rpManager->unsubscribeGroup(g_rpManager->currentGroup()))
slotCollectionSelected(0);
}
@@ -1588,7 +1588,7 @@ void KNMainWidget::slotFolDelete()
KMessageBox::sorry(knGlobals.topWidget, i18n("You cannot delete a standard folder."));
else if( KMessageBox::Continue==KMessageBox::warningContinueCancel(knGlobals.topWidget,
- i18n("Do you really want to delete this folder and all its tqchildren?"),"",KGuiItem(i18n("&Delete"),"editdelete")) ) {
+ i18n("Do you really want to delete this folder and all its children?"),"",KGuiItem(i18n("&Delete"),"editdelete")) ) {
if(!f_olManager->deleteFolder(f_olManager->currentFolder()))
KMessageBox::sorry(knGlobals.topWidget,
@@ -1639,7 +1639,7 @@ void KNMainWidget::slotFolEmpty()
return;
}
if( KMessageBox::Continue == KMessageBox::warningContinueCancel(
- this, i18n("Do you really want to delete all articles in %1?").tqarg(f_olManager->currentFolder()->name()),"",KGuiItem(i18n("&Delete"),"editdelete")) )
+ this, i18n("Do you really want to delete all articles in %1?").arg(f_olManager->currentFolder()->name()),"",KGuiItem(i18n("&Delete"),"editdelete")) )
f_olManager->emptyFolder(f_olManager->currentFolder());
}
}
@@ -1948,7 +1948,7 @@ void KNMainWidget::slotFetchArticleWithID()
TQString id = dlg->messageId().simplifyWhiteSpace();
if (id.find(TQRegExp("*@*",false,true))!=-1) {
if (id.find(TQRegExp("<*>",false,true))==-1) // add "<>" when necessary
- id = TQString("<%1>").tqarg(id);
+ id = TQString("<%1>").arg(id);
if(!KNArticleWindow::raiseWindowForArticle(id.latin1())) { //article not yet opened
KNRemoteArticle *a=new KNRemoteArticle(g_rpManager->currentGroup());
diff --git a/knode/knmainwidget.h b/knode/knmainwidget.h
index 6a6e8ed1..fffd22b4 100644
--- a/knode/knmainwidget.h
+++ b/knode/knmainwidget.h
@@ -73,8 +73,8 @@ public:
void prepareShutdown();
//GUI
- void seStatusMsg(const TQString& = TQString(), int id=SB_MAIN);
- void seStatusHelpMsg(const TQString& text);
+ void setStatusMsg(const TQString& = TQString(), int id=SB_MAIN);
+ void setStatusHelpMsg(const TQString& text);
void updateCaption();
void setCursorBusy(bool b=true);
void blockUI(bool b=true);
diff --git a/knode/knmemorymanager.cpp b/knode/knmemorymanager.cpp
index 365e9f8c..37a63928 100644
--- a/knode/knmemorymanager.cpp
+++ b/knode/knmemorymanager.cpp
@@ -162,7 +162,7 @@ void KNMemoryManager::checkMemoryUsageCollections()
for ( TQValueList<CollectionItem*>::Iterator it = tempList.begin(); it != tempList.end(); ) {
if ( c_ollCacheSize <= maxSize )
break;
- // unloadHeaders() will remove the cache entry and thus tqinvalidate the iterator!
+ // unloadHeaders() will remove the cache entry and thus invalidate the iterator!
c = (*it)->col;
++it;
@@ -191,7 +191,7 @@ void KNMemoryManager::checkMemoryUsageArticles()
for ( TQValueList<ArticleItem*>::Iterator it = mArtList.begin(); it != mArtList.end(); ) {
if ( a_rtCacheSize <= maxSize )
break;
- // unloadArticle() will remove the cache entry and thus tqinvalidate the iterator!
+ // unloadArticle() will remove the cache entry and thus invalidate the iterator!
KNArticle *art = (*it)->art;
++it;
knGlobals.articleManager()->unloadArticle( art, false ); // *try* to unload
diff --git a/knode/knnetaccess.cpp b/knode/knnetaccess.cpp
index 1b67d62e..92e7de23 100644
--- a/knode/knnetaccess.cpp
+++ b/knode/knnetaccess.cpp
@@ -102,7 +102,7 @@ void KNNetAccess::addJob(KNJobData *job)
if ( !job->account()->readyForLogin() ) {
mWalletQueue.append( job );
knGlobals.accountManager()->loadPasswordsAsync();
- job->seStatus( i18n( "Waiting for KWallet..." ) );
+ job->setStatus( i18n( "Waiting for KWallet..." ) );
return;
}
@@ -332,7 +332,7 @@ void KNNetAccess::threadDoneNntp()
currentNntpJob = 0L;
currMsg = TQString();
- knGlobals.seStatusMsg();
+ knGlobals.setStatusMsg();
tmp->setComplete();
tmp->notifyConsumer();
@@ -359,7 +359,7 @@ void KNNetAccess::threadDoneSmtp()
currentSmtpJob = 0L;
if (!currentNntpJob) {
currMsg = TQString();
- knGlobals.seStatusMsg();
+ knGlobals.setStatusMsg();
}
tmp->setComplete();
@@ -398,53 +398,53 @@ void KNNetAccess::slotThreadSignal(int i)
break;
case KNProtocolClient::TSconnect:
currMsg = i18n(" Connecting to server...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSloadGrouplist:
currMsg = i18n(" Loading group list from disk...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSwriteGrouplist:
currMsg = i18n(" Writing group list to disk...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSdownloadGrouplist:
currMsg = i18n(" Downloading group list...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSdownloadNewGroups:
currMsg = i18n(" Looking for new groups...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSdownloadDesc:
currMsg = i18n(" Downloading group descriptions...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSdownloadNew:
currMsg = i18n(" Downloading new headers...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSsortNew:
currMsg = i18n(" Sorting...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSdownloadArticle:
currMsg = i18n(" Downloading article...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSsendArticle:
currMsg = i18n(" Sending article...");
- knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ knGlobals.setStatusMsg(currMsg);
+ currentNntpJob->setStatus(currMsg);
break;
case KNProtocolClient::TSjobStarted:
currentNntpJob->setProgress(0);
@@ -477,7 +477,7 @@ void KNNetAccess::slotPasswordsChanged()
{
TQValueList<KNJobData*>::ConstIterator it;
for ( it = mWalletQueue.begin(); it != mWalletQueue.end(); ++it ) {
- (*it)->seStatus( i18n("Waiting...") );
+ (*it)->setStatus( i18n("Waiting...") );
if ( (*it)->type() == KNJobData::JTmail )
smtpJobQueue.append( (*it) );
else
diff --git a/knode/knnntpaccount.cpp b/knode/knnntpaccount.cpp
index 8aa5f1b7..ba1657c0 100644
--- a/knode/knnntpaccount.cpp
+++ b/knode/knnntpaccount.cpp
@@ -174,7 +174,7 @@ void KNNntpAccount::saveInfo()
TQString KNNntpAccount::path()
{
- TQString dir(locateLocal("data","knode/")+TQString("nntp.%1/").tqarg(i_d));
+ TQString dir(locateLocal("data","knode/")+TQString("nntp.%1/").arg(i_d));
if (dir.isNull())
KNHelper::displayInternalFileError();
return (dir);
diff --git a/knode/knnntpclient.cpp b/knode/knnntpclient.cpp
index fbd8ce51..efc3b18c 100644
--- a/knode/knnntpclient.cpp
+++ b/knode/knnntpclient.cpp
@@ -336,7 +336,7 @@ void KNNntpClient::doFetchNewHeaders()
sendSignal(TSdownloadNew);
errorPrefix=i18n("No new articles could be retrieved for\n%1/%2.\nThe following error occurred:\n")
- .tqarg(account.server()).tqarg(target->groupname());
+ .arg(account.server()).arg(target->groupname());
cmd="GROUP ";
cmd+=target->groupname().utf8();
@@ -482,7 +482,7 @@ void KNNntpClient::doFetchArticle()
job->setErrorString( errorPrefix + getCurrentLine() +
i18n("<br><br>The article you requested is not available on your news server."
"<br>You could try to get it from <a href=\"http://groups.google.com/groups?selm=%1\">groups.google.com</a>.")
- .tqarg( msgId ) );
+ .arg( msgId ) );
}
return;
}
@@ -638,7 +638,7 @@ bool KNNntpClient::openConnection()
#ifndef NDEBUG
qDebug("knode: Authorization failed");
#endif
- job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
+ job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
job->setAuthError(true);
closeConnection();
return false;
@@ -695,7 +695,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
//qDebug("knode: Password required");
if (!account.pass().length()) {
- job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
+ job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
job->setAuthError(true);
closeConnection();
return false;
@@ -716,7 +716,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
if (!KNProtocolClient::sendCommand(cmd,rep)) // retry the original command
return false;
} else {
- job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
+ job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
job->setAuthError(true);
closeConnection();
return false;
@@ -729,7 +729,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
void KNNntpClient::handleErrors()
{
if (errorPrefix.isEmpty())
- job->setErrorString(i18n("An error occurred:\n%1").tqarg(getCurrentLine()));
+ job->setErrorString(i18n("An error occurred:\n%1").arg(getCurrentLine()));
else
job->setErrorString(errorPrefix + getCurrentLine());
diff --git a/knode/knprotocolclient.cpp b/knode/knprotocolclient.cpp
index dd0db677..330199bd 100644
--- a/knode/knprotocolclient.cpp
+++ b/knode/knprotocolclient.cpp
@@ -201,11 +201,11 @@ bool KNProtocolClient::openConnection()
if (ks.status() == IO_LookupError) {
job->setErrorString(i18n("Unable to resolve hostname"));
} else if (ks.status() == IO_ConnectError) {
- job->setErrorString(i18n("Unable to connect:\n%1").tqarg(KExtendedSocket::strError(ks.status(), errno)));
+ job->setErrorString(i18n("Unable to connect:\n%1").arg(KExtendedSocket::strError(ks.status(), errno)));
} else if (ks.status() == IO_TimeOutError)
job->setErrorString(i18n("A delay occurred which exceeded the\ncurrent timeout limit."));
else
- job->setErrorString(i18n("Unable to connect:\n%1").tqarg(KExtendedSocket::strError(ks.status(), errno)));
+ job->setErrorString(i18n("Unable to connect:\n%1").arg(KExtendedSocket::strError(ks.status(), errno)));
closeSocket();
return false;
@@ -432,7 +432,7 @@ bool KNProtocolClient::checkNextResponse(int code)
void KNProtocolClient::handleErrors()
{
if (errorPrefix.isEmpty())
- job->setErrorString(i18n("An error occurred:\n%1").tqarg(thisLine));
+ job->setErrorString(i18n("An error occurred:\n%1").arg(thisLine));
else
job->setErrorString(errorPrefix + thisLine);
diff --git a/knode/knserverinfo.cpp b/knode/knserverinfo.cpp
index c0351349..d314a771 100644
--- a/knode/knserverinfo.cpp
+++ b/knode/knserverinfo.cpp
@@ -111,7 +111,7 @@ void KNServerInfo::saveConf(KConfig *conf)
"but should not be considered secure from decryption efforts "
"if access to the configuration file is obtained.\n"
"Do you want to store the password for server '%1' in the "
- "configuration file?").tqarg( server() ),
+ "configuration file?").arg( server() ),
i18n("KWallet Not Available"),
KGuiItem( i18n("Store Password") ),
KGuiItem( i18n("Do Not Store Password") ) )
diff --git a/knode/utilities.cpp b/knode/utilities.cpp
index 2297387b..6d349336 100644
--- a/knode/utilities.cpp
+++ b/knode/utilities.cpp
@@ -167,7 +167,7 @@ TQFile* KNSaveHelper::getFile(const TQString &dialogTitle)
if (url.isLocalFile()) {
if (TQFileInfo(url.path()).exists() &&
(KMessageBox::warningContinueCancel(knGlobals.topWidget,
- i18n("<qt>A file named <b>%1</b> already exists.<br>Do you want to replace it?</qt>").tqarg(url.path()),
+ i18n("<qt>A file named <b>%1</b> already exists.<br>Do you want to replace it?</qt>").arg(url.path()),
dialogTitle, i18n("&Replace")) != KMessageBox::Continue)) {
return 0;
}
@@ -293,7 +293,7 @@ int KNHelper::selectDialog(TQWidget *parent, const TQString &caption, const TQSt
return ret;
}
-// **** window tqgeometry managing *********************************************
+// **** window geometry managing *********************************************
void KNHelper::saveWindowSize(const TQString &name, const TQSize &s)
{
diff --git a/knode/headerview.cpp b/knode/headerview.cpp
index c3fa5307..0498b99c 100644
--- a/knode/headerview.cpp
+++ b/knode/headerview.cpp
@@ -64,7 +64,7 @@ KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
setColumnAlignment( mPaintInfo.sizeCol, TQt::AlignRight );
setColumnAlignment( mPaintInfo.scoreCol, TQt::AlignRight );
// due to our own column text squeezing we need to tqrepaint on column resizing
disconnect( header(), TQT_SIGNAL(sizeChange(int, int, int)) );
connect( header(), TQT_SIGNAL(sizeChange(int, int, int)),
TQT_SLOT(slotSizeChanged(int, int, int)) );
@@ -534,7 +534,7 @@ TQDragObject* KNHeaderView::dragObject()
void KNHeaderView::slotSizeChanged( int section, int, int newSize )
{
- viewport()->tqrepaint( header()->sectionPos(section), 0, newSize, visibleHeight(), false);
+ viewport()->repaint( header()->sectionPos(section), 0, newSize, visibleHeight(), false);
}
@@ -64,7 +64,7 @@ KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
setColumnAlignment( mPaintInfo.sizeCol, TQt::AlignRight );
setColumnAlignment( mPaintInfo.scoreCol, TQt::AlignRight );
- // due to our own column text squeezing we need to tqrepaint on column resizing
+ // due to our own column text squeezing we need to repaint on column resizing
disconnect( header(), TQT_SIGNAL(sizeChange(int, int, int)) );
connect( header(), TQT_SIGNAL(sizeChange(int, int, int)),
diff --git a/knode/knglobals.h b/knode/knglobals.h
index c8371b46..9db4f22e 100644
--- a/knode/knglobals.h
+++ b/knode/knglobals.h
@@ -75,8 +75,8 @@ class KDE_EXPORT KNGlobals {
KNScoringManager *scoringManager();
KNMemoryManager *memoryManager();
- /** forwarded to top->seStatusMsg() if available */
- void seStatusMsg(const TQString& text = TQString(), int id = SB_MAIN);
+ /** forwarded to top->setStatusMsg() if available */
+ void setStatusMsg(const TQString& text = TQString(), int id = SB_MAIN);
private:
KSharedConfig::Ptr c_onfig;